/******************************************************************************
 **																			 **
 ** 	Module:		QD3DUIView.h											 **
 ** 																		 **
 ** 																		 **
 ** 	Purpose: 															 **
 ** 																		 **
 ** 																		 **
 ** 																		 **
 ** 	Copyright (C) 1992-1995 Apple Computer, Inc.  All rights reserved.	 **
 ** 																		 **
 ** 																		 **
 *****************************************************************************/
#if defined(ESCHER_VER_15) && ESCHER_VER_15

#ifndef UIView_h
#define UIView_h

#if PRAGMA_ONCE
	#pragma once
#endif

#if defined(WINDOW_SYSTEM_MACINTOSH) && WINDOW_SYSTEM_MACINTOSH

#include <Quickdraw.h>
#include <Windows.h>
#include <FixMath.h>
#include <GXTypes.h>

#endif  /*  WINDOW_SYSTEM_MACINTOSH  */

#include "QD3DMapping.h"

#if defined(THINK_C) || defined(__SC__)
	#pragma options(!pack_enums, !align_arrays)
	#pragma SC options align=power
#elif defined(__MWERKS__)
	#pragma enumsalwaysint on
	#pragma align_array_members off
	#pragma options align=native
#elif defined(__PPCC__)
	#pragma options align=power
#elif defined(__xlc) || defined(__xlC) || defined(__xlC__) || defined(__XLC121__)
	#pragma options enum=int
#endif

#ifdef __cplusplus
extern "C" {
#endif	/* __cplusplus */

/******************************************************************************
 **																			 **
 **							User Interface View API							 **
 **																			 **
 *****************************************************************************/
 
QD3D_EXPORT TQ3UIViewObject Q3UIView_New(
	void);

QD3D_EXPORT TQ3Status Q3UIView_SetScale(
	TQ3UIViewObject				uiViewObject,
	float						scaleFactor);

QD3D_EXPORT TQ3Status Q3UIView_SetScaleAtDistance(
	TQ3UIViewObject				uiViewObject,
	float						distance);

QD3D_EXPORT TQ3Status Q3UIView_GetScale(
	TQ3UIViewObject				uiViewObject,
	float						*scaleFactor);

QD3D_EXPORT TQ3Status Q3UIView_SetColorScheme(
	TQ3UIViewObject				uiViewObject,
	TQ3ColorSchemeObject			colorScheme);

QD3D_EXPORT TQ3Status Q3UIView_GetColorScheme(
	TQ3UIViewObject				uiViewObject,
	TQ3ColorSchemeObject			*colorScheme);


QD3D_EXPORT TQ3Status Q3UIView_SetMapping(
	TQ3UIViewObject		uiViewObject,
	TQ3MappingObject	mapping);

QD3D_EXPORT TQ3Status Q3UIView_GetMapping(
	TQ3UIViewObject		uiViewObject,
	TQ3MappingObject	*mapping);

QD3D_EXPORT TQ3Status Q3UIView_TrackMapping(
	TQ3UIViewObject		uiViewObject,
	TQ3Point2D			*screenPoint,
	TQ3MappingInfoMask	requestInfo,
	TQ3MappingInfo		*info);

QD3D_EXPORT TQ3Status Q3UIView_EmptyMapping(
	TQ3MappingInfo		*info);
	
	
#if defined(WINDOW_SYSTEM_MACINTOSH) && WINDOW_SYSTEM_MACINTOSH

/******************************************************************************
 **																			 **
 **									 Routines								 **
 **																			 **
 *****************************************************************************/

QD3D_EXPORT void Q3UIView_SetQDDisplay(
	TQ3UIViewObject		uiViewObject,
	WindowPtr			window,
	const Rect			*bounds);

QD3D_EXPORT void Q3UIView_SetQDGXDisplay(
	TQ3UIViewObject		uiViewObject,
	gxViewPort			viewPort,
	gxShape				shape);


#endif	/*  WINDOW_SYSTEM_MACINTOSH  */

/******************************************************************************
 **																			 **
 **								Type Definitions							 **
 **																			 **
 *****************************************************************************/

typedef enum TQ3ColorSchemeAttributeSet{
	kQ3ColorSchemeAttributeSetCursor,
	kQ3ColorSchemeAttributeSetSparkle,
	kQ3ColorSchemeAttributeSetHandle,
	kQ3ColorSchemeAttributeSetStructure,
	kQ3ColorSchemeAttributeSetRoomFloor1,
	kQ3ColorSchemeAttributeSetRoomFloor2,
	kQ3ColorSchemeAttributeSetRoomWall,
	kQ3ColorSchemeAttributeSetRoomCeiling,
	kQ3ColorSchemeAttributeSetConstraint,
	kQ3ColorSchemeAttributeSetConstraint2,
	kQ3ColorSchemeAttributeSetCOUNT
} TQ3ColorSchemeAttributeSet;


/******************************************************************************
 **																			 **
 **									 Routines								 **
 **																			 **
 *****************************************************************************/

QD3D_EXPORT TQ3Status Q3ColorScheme_Next(
	TQ3ColorSchemeObject		colorSchemeObject,
	TQ3ColorSchemeObject		*nextColorScheme);

QD3D_EXPORT TQ3Status Q3ColorScheme_GetInfo(
	TQ3ColorSchemeObject		colorSchemeObject,
	char						*name,
	unsigned long				nameLength);

QD3D_EXPORT TQ3Status Q3ColorScheme_GetAttributeSet(
	TQ3ColorSchemeObject		colorSchemeObject,
	TQ3ColorSchemeAttributeSet	attributeSetIndex,
	TQ3AttributeSet				*attributeSet);

QD3D_EXPORT TQ3ColorSchemeObject Q3ColorScheme_New(
	const char					*name,
	unsigned long				attributeSetCount,
	TQ3AttributeSet				attributeSetArray[]);


#ifdef __cplusplus
}
#endif	/* __cplusplus */

#if defined(__MWERKS__)
	#pragma enumsalwaysint reset
#elif defined(__xlc) || defined(__xlC) || defined(__xlC__) || defined(__XLC121__)
	#pragma options enum=reset
#endif

#endif  /*  UIView_h  */

#endif	/* ESCHER_VER_15 */
